---
name: "🌟新功能"
about: "想要钻石铲能够做些新东西"
labels: type:feature
---

# 新功能提案

<!-- 请确保这个新功能是需要放置在钻石铲核心, 而不是能够通过新的插件来补充的功能 -->
<!-- 当然如果你有想法可以直接提出pr -->

## 基本信息

<!-- 请简要描述大致的功能, 需要做什么之类的 -->

## 需求背景

<!-- 如果可以, 请告诉我为什么要添加这个新功能 -->

## 方案设计 (可选)

<!-- 如果您有大致的方案规划, 可以直接告诉我们 -->

---
Current template created on 2025-04-10 by stupidfish.